@@ -17,7 +17,7 @@ require Moo::Role;
 
 use namespace::clean;
 
-our $VERSION = '2.09';
+our $VERSION = '2.10';
 
 # more clear error messages in some crucial cases
 our @CARP_NOT = qw(Form::Tiny Form::Tiny::Form);
@@ -44,6 +44,12 @@ has 'is_flat' => (
 	default => sub { 1 },
 );
 
+has 'is_dynamic' => (
+	is => 'ro',
+	writer => 'set_dynamic',
+	default => sub { 0 },
+);
+
 has 'hooks' => (
 	is => 'ro',
 	writer => 'set_hooks',
@@ -80,6 +86,13 @@ has 'messages' => (
 	default => sub { {} },
 );
 
+has 'static_blueprint' => (
+	is => 'ro',
+	isa => HashRef,
+	lazy => 1,
+	builder => '_build_blueprint',
+);
+
 sub set_package
 {
 	my ($self, $package) = @_;
@@ -196,7 +209,7 @@ sub resolved_fields
 {
 	my ($self, $object) = @_;
 
-	return [@{$self->fields}] if $self->is_flat;
+	return [@{$self->fields}] if !$self->is_dynamic;
 
 	croak 'resolved_fields requires form object'
 		unless defined blessed $object;
@@ -226,10 +239,13 @@ sub add_field
 	my $builder = Form::Tiny::FieldDefinitionBuilder->new(data => $scalar_param)->build;
 	push @{$self->fields}, $builder;
 
-	if ($self->is_flat && ($builder->isa('Form::Tiny::FieldDefinitionBuilder') || @{$builder->get_name_path->path} > 1))
-	{
-		$self->set_flat(0);
-	}
+	$self->set_dynamic(1)
+		if $builder->isa('Form::Tiny::FieldDefinitionBuilder');
+
+	# NOTE: we can only know if the form is flat if it is not dynamic
+	# otherwise we need to assume it is not flat
+	$self->set_flat(0)
+		if $self->is_dynamic || @{$builder->get_name_path->path} > 1;
 
 	return $builder;
 }
@@ -283,7 +299,6 @@ sub inherit_roles_from
 
 	if (defined $parent) {
 		$self->set_meta_roles([uniq(@{$parent->meta_roles}, @{$self->meta_roles})]);
-		$self->set_form_roles([uniq(@{$parent->form_roles}, @{$self->form_roles})]);
 	}
 
 	Moo::Role->apply_roles_to_object(
@@ -328,8 +343,66 @@ sub inherit_from
 	);
 
 	$self->set_flat($parent->is_flat);
+	$self->set_dynamic($parent->is_dynamic);
 
 	return $self;
 }
 
+# Builds a "blueprint" of form fields. It will describe how the 'fields' hashref should look like
+# Since we don't know anything about dynamic fields in meta context,
+# croaks if it encounters any such field in the main form or any of the subforms
+sub _build_blueprint
+{
+	my ($self, $context) = @_;
+	my %result;
+
+	croak "Can't create a blueprint of a dynamic form"
+		if $self->is_dynamic && !$context;
+
+	# if context is given, get the cached resolved fields from it
+	# note: context will never be passed when it is called by Moo to build 'blueprint'
+	my $fields = $context ? $context->field_defs : $self->fields;
+
+	for my $def (@$fields) {
+		my $value = $def;
+		if ($def->is_subform) {
+			my $meta = get_package_form_meta(ref $def->type);
+			$value = $meta->blueprint($def->type);
+		}
+
+		my @meta = @{$def->get_name_path->meta};
+		my @path = @{$def->get_name_path->path};
+
+		# adjust path so that instead of stars (*) we get zeros
+		@path = map { $meta[$_] eq 'ARRAY' ? 0 : $path[$_] } keys @path;
+
+		Form::Tiny::Utils::_assign_field(
+			\%result,
+			$def, [
+				{
+					path => \@path,
+					value => $value
+				}
+			]
+		);
+	}
+
+	return \%result;
+}
+
+# Builds a "blueprint" of form fields in the object context
+# Note: does not cache the result like 'blueprint' does.
+sub blueprint
+{
+	my ($self, $context) = @_;
+
+	if ($self->is_dynamic) {
+		return $self->_build_blueprint($context);
+	}
+	else {
+		return $self->static_blueprint;
+	}
+}
+
 1;
+
